use mio::Token;

use crate::command::Command;
use crate::database::Db;
use crate::queue::SendQueue;
use crate::{try_option_send_error, try_send_error};

/// Say something to anyone in the room.
pub fn say(_: &Command, args: String, token: Token, db: &mut Db) -> SendQueue {
	let mut send_queue = SendQueue::new();

	let player = try_option_send_error!(token, db.get_connected_player(token));

	for (neighbor_token, _) in try_send_error!(
		token,
		db.find_connected_players_by_location(player.location)
	) {
		send_queue.push(
			neighbor_token,
			if neighbor_token == token {
				format!("You say, \"{}\"\n", args)
			} else {
				format!("{} says, \"{}\"\n", player.name, args)
			},
			true,
		);
	}

	send_queue
}
