use std::path::PathBuf;

use serde_derive::Deserialize;

use crate::config::*;
use crate::file;
use crate::id::Id;
use crate::result::RudeResult;

/// Game configuration
#[derive(Clone, Debug, Deserialize)]
pub struct Config {
	/// Directory to hold world and players
	pub database: PathBuf,

	/// Server configuration
	pub server: Server,

	/// Logging configuration
	pub logging: Logging,

	/// Default starting location
	pub starting_location: Id,
}

impl Config {
	/// Load and deserialize the toml configuration from the given file.
	pub fn load<P: Into<PathBuf>>(path: P) -> RudeResult<Self> {
		Ok(file::read_print(&path.into())?)
	}
}
